@@ -46,12 +46,13 @@ makeConnectString(char *connect_string, const ConnInfo *ci, UWORD len)
 	BOOL		abbrev = (len < 1024);
 
 	/* fundamental info */
-	sprintf(connect_string, "%s=%s;DATABASE=%s;SERVER=%s;PORT=%s;UID=%s;PWD=%s",
+	sprintf(connect_string, "%s=%s;DATABASE=%s;SERVER=%s;PORT=%s;SSLMODE=%s;UID=%s;PWD=%s",
 			got_dsn ? "DSN" : "DRIVER",
 			got_dsn ? ci->dsn : ci->drivername,
 			ci->database,
 			ci->server,
 			ci->port,
+            ci->sslmode,
 			ci->username,
 			ci->password);
 
@@ -201,7 +202,7 @@ makeConnectString(char *connect_string, const ConnInfo *ci, UWORD len)
 				ci->int8_as,
 				ci->drivers.extra_systable_prefixes,
 				EFFECTIVE_BIT_COUNT,
-				flag);
+				(long unsigned int) flag);
 	}
 }
 
@@ -214,7 +215,7 @@ unfoldCXAttribute(ConnInfo *ci, const char *value)
 	if (strlen(value) < 2)
 	{
 		count = 3;
-		sscanf(value, "%lx", &flag);
+		sscanf(value, "%lx", (long unsigned int *) &flag);
 	}
 	else
 	{
@@ -222,7 +223,7 @@ unfoldCXAttribute(ConnInfo *ci, const char *value)
 		memcpy(cnt, value, 2);
 		cnt[2] = '\0';
 		sscanf(cnt, "%x", &count);
-		sscanf(value + 2, "%lx", &flag);
+		sscanf(value + 2, "%lx", (long unsigned int *) &flag);
 	}
 	ci->disallow_premature = (char)((flag & BIT_DISALLOWPREMATURE) != 0);
 	ci->allow_keyset = (char)((flag & BIT_UPDATABLECURSORS) != 0);
@@ -285,11 +286,9 @@ copyAttributes(ConnInfo *ci, const char *attribute, const char *value)
 
 	else if (stricmp(attribute, INI_PORT) == 0)
 		strcpy(ci->port, value);
-
-#ifdef HAVE_UNIX_SOCKETS
-	else if (stricmp(attribute, INI_UDS) == 0)
-		strcpy(ci->uds, value);
-#endif
+    
+	else if (stricmp(attribute, INI_SSLMODE) == 0 || stricmp(attribute, "sslmode") == 0)
+		strcpy(ci->sslmode, value);
 
 	else if (stricmp(attribute, INI_READONLY) == 0 || stricmp(attribute, "A0") == 0)
 		strcpy(ci->onlyread, value);
@@ -333,7 +332,7 @@ copyAttributes(ConnInfo *ci, const char *attribute, const char *value)
 	else if (stricmp(attribute, "CX") == 0)
 		unfoldCXAttribute(ci, value);
 
-	mylog("copyAttributes: DSN='%s',server='%s',dbase='%s',user='%s',passwd='%s',port='%s',onlyread='%s',protocol='%s',conn_settings='%s',disallow_premature=%d)\n", ci->dsn, ci->server, ci->database, ci->username, ci->password ? "xxxxx" : "", ci->port, ci->onlyread, ci->protocol, ci->conn_settings, ci->disallow_premature);
+	mylog("copyAttributes: DSN='%s',server='%s',dbase='%s',user='%s',passwd='%s',port='%s',sslmode='%s',onlyread='%s',protocol='%s',conn_settings='%s',disallow_premature=%d)\n", ci->dsn, ci->server, ci->database, ci->username, ci->password ? "xxxxx" : "", ci->port, ci->sslmode, ci->onlyread, ci->protocol, ci->conn_settings, ci->disallow_premature);
 }
 
 void
@@ -404,6 +403,9 @@ getDSNdefaults(ConnInfo *ci)
 {
 	if (ci->port[0] == '\0')
 		strcpy(ci->port, DEFAULT_PORT);
+    
+	if (ci->sslmode[0] == '\0')
+		strcpy(ci->sslmode, DEFAULT_SSLMODE);
 
 	if (ci->onlyread[0] == '\0')
 		sprintf(ci->onlyread, "%d", globals.onlyread);
@@ -497,11 +499,9 @@ getDSNinfo(ConnInfo *ci, char overwrite)
 	if (ci->port[0] == '\0' || overwrite)
 		SQLGetPrivateProfileString(DSN, INI_PORT, "", ci->port, sizeof(ci->port), ODBC_INI);
 
-#ifdef HAVE_UNIX_SOCKETS
-	if (ci->uds[0] == '\0' || overwrite)
-		SQLGetPrivateProfileString(DSN, INI_UDS, "", ci->uds, sizeof(ci->uds), ODBC_INI);
-#endif
-
+	if (ci->sslmode[0] == '\0' || overwrite)
+		SQLGetPrivateProfileString(DSN, INI_SSLMODE, "", ci->sslmode, sizeof(ci->sslmode), ODBC_INI);
+    
 	if (ci->onlyread[0] == '\0' || overwrite)
 		SQLGetPrivateProfileString(DSN, INI_READONLY, "", ci->onlyread, sizeof(ci->onlyread), ODBC_INI);
 
@@ -734,13 +734,11 @@ writeDSNinfo(const ConnInfo *ci)
 								 INI_PORT,
 								 ci->port,
 								 ODBC_INI);
-
-#ifdef HAVE_UNIX_SOCKETS
+                                 
 	SQLWritePrivateProfileString(DSN,
-								 INI_UDS,
-								 ci->uds,
+								 INI_SSLMODE,
+								 ci->sslmode,
 								 ODBC_INI);
-#endif
 
 	SQLWritePrivateProfileString(DSN,
 								 INI_USER,
