@@ -18,6 +18,7 @@
 #include <stdio.h>
 #include <string.h>
 
+#include <libpq/libpq-fs.h>
 #include "environ.h"
 #include "connection.h"
 #include "statement.h"
@@ -25,7 +26,6 @@
 #include "convert.h"
 #include "bind.h"
 #include "pgtypes.h"
-#include "lobj.h"
 #include "pgapifunc.h"
 
 /*extern GLOBAL_VALUES globals;*/
@@ -226,7 +226,7 @@ RETCODE	Exec_with_parameters_resolved(StatementClass *stmt, BOOL *exec_end)
 
 	/*
 	 *	Dummy exection to get the column info.
-	 */ 
+	 */
 	if (stmt->inaccurate_result && conn->connInfo.disallow_premature)
 	{
 		BOOL		in_trans = CC_is_in_trans(conn);
@@ -301,7 +301,7 @@ RETCODE	Exec_with_parameters_resolved(StatementClass *stmt, BOOL *exec_end)
 		if (res && QR_command_maybe_successful(res))
 		{
 			QResultClass	*kres;
-		
+
 			kres = res->next;
 			SC_set_Result(stmt, kres);
 			res->next = NULL;
@@ -323,13 +323,13 @@ RETCODE	Exec_with_parameters_resolved(StatementClass *stmt, BOOL *exec_end)
 	{
 		switch (retval)
 		{
-			case SQL_SUCCESS: 
+			case SQL_SUCCESS:
 				ipdopts->param_status_ptr[stmt->exec_current_row] = SQL_PARAM_SUCCESS;
 				break;
-			case SQL_SUCCESS_WITH_INFO: 
+			case SQL_SUCCESS_WITH_INFO:
 				ipdopts->param_status_ptr[stmt->exec_current_row] = SQL_PARAM_SUCCESS_WITH_INFO;
 				break;
-			default: 
+			default:
 				ipdopts->param_status_ptr[stmt->exec_current_row] = SQL_PARAM_ERROR;
 				break;
 		}
@@ -352,22 +352,12 @@ RETCODE	Exec_with_parameters_resolved(StatementClass *stmt, BOOL *exec_end)
 	{
 
         	EnvironmentClass *env = (EnvironmentClass *) (conn->henv);
-		const char *cmd = QR_get_command(res);
-
-		if (retval == SQL_SUCCESS && cmd && EN_is_odbc3(env))
+		if (!res->recent_processed_row_count && res->status == PGRES_COMMAND_OK && EN_is_odbc3(env))
 		{
-			int	count;
-
-			if (sscanf(cmd , "UPDATE %d", &count) == 1)
-				;
-			else if (sscanf(cmd , "DELETE %d", &count) == 1)
-				;
-			else
-				count = -1;
-			if (0 == count)
-				retval = SQL_NO_DATA;
+			if ((strnicmp(stmt->statement, "UPDATE", 6) == 0) || 
+				(strnicmp(stmt->statement, "DELETE", 6) == 0))
+				retval = SQL_NO_DATA_FOUND;
 		}
-
 		stmt->diag_row_count = res->recent_processed_row_count;
 	}
 	/*
@@ -391,8 +381,7 @@ PGAPI_Execute(HSTMT hstmt, UWORD flag)
 	StatementClass *stmt = (StatementClass *) hstmt;
 	APDFields	*apdopts;
 	IPDFields	*ipdopts;
-	int			i,
-				retval, start_row, end_row;
+	int	i, 	retval, start_row, end_row;
 	BOOL	exec_end, recycled = FALSE, recycle = TRUE;
 
 	mylog("%s: entering...\n", func);
@@ -493,9 +482,9 @@ PGAPI_Execute(HSTMT hstmt, UWORD flag)
 	}
 
 	if (start_row = stmt->exec_start_row, start_row < 0)
-		start_row = 0; 
+		start_row = 0;
 	if (end_row = stmt->exec_end_row, end_row < 0)
-		end_row = apdopts->paramset_size - 1; 
+		end_row = apdopts->paramset_size - 1;
 	if (stmt->exec_current_row < 0)
 		stmt->exec_current_row = start_row;
 	ipdopts = SC_get_IPDF(stmt);
@@ -505,7 +494,7 @@ PGAPI_Execute(HSTMT hstmt, UWORD flag)
 			*ipdopts->param_processed_ptr = 0;
 
 		/*
-	 	 *	Initialize the param_status_ptr 
+	 	 *	Initialize the param_status_ptr
 	 	 */
 		if (ipdopts->param_status_ptr)
 		{
@@ -532,7 +521,7 @@ next_param_row:
 		}
 	}
 	/*
-	 *	Initialize the current row status 
+	 *	Initialize the current row status
 	 */
 	if (ipdopts->param_status_ptr)
 		ipdopts->param_status_ptr[stmt->exec_current_row] = SQL_PARAM_ERROR;
@@ -553,7 +542,7 @@ next_param_row:
 		Int4	current_row = stmt->exec_current_row < 0 ? 0 : stmt->exec_current_row;
 
 		/*
-		 *	Increment the  number of currently processed rows 
+		 *	Increment the  number of currently processed rows
 		 */
 		if (ipdopts->param_processed_ptr)
 			(*ipdopts->param_processed_ptr)++;
@@ -866,7 +855,7 @@ PGAPI_ParamData(
 	/* close the large object */
 	if (estmt->lobj_fd >= 0)
 	{
-		lo_close(estmt->hdbc, estmt->lobj_fd);
+		lo_close(estmt->hdbc->pgconn, estmt->lobj_fd);
 
 		/* commit transaction if needed */
 		if (!ci->drivers.use_declarefetch && CC_is_in_autocommit(estmt->hdbc))
@@ -917,7 +906,7 @@ PGAPI_ParamData(
 				if (stmt->execute_delegate)
 				{
 					UInt4	offset = apdopts->param_offset_ptr ? *apdopts->param_offset_ptr : 0;
-					UInt4	perrow = apdopts->param_bind_type > 0 ? apdopts->param_bind_type : apdopts->parameters[i].buflen; 
+					UInt4	perrow = apdopts->param_bind_type > 0 ? apdopts->param_bind_type : apdopts->parameters[i].buflen;
 
 					*prgbValue = apdopts->parameters[i].buffer + offset + estmt->exec_current_row * perrow;
 				}
@@ -987,12 +976,14 @@ PGAPI_PutData(
 		ctype = sqltype_to_default_ctype(conn, current_iparam->SQLType);
 	if (SQL_NTS == cbValue)
 	{
+#ifdef  UNICODE_SUPPORT
 		if (SQL_C_WCHAR == ctype)
 		{
 			putlen = WCLEN * ucs2strlen((SQLWCHAR *) rgbValue);
 			lenset = TRUE;
 		}
 		else
+#endif /* UNICODE_SUPPORT */
 		if (SQL_C_CHAR == ctype)
 		{
 			putlen = strlen(rgbValue);
@@ -1004,7 +995,11 @@ PGAPI_PutData(
 		if (cbValue < 0)
 			putlen = cbValue;
 		else
+#ifdef  UNICODE_SUPPORT
 		if (ctype == SQL_C_CHAR || ctype == SQL_C_BINARY || ctype == SQL_C_WCHAR)
+#else 	 
+		if (ctype == SQL_C_CHAR || ctype == SQL_C_BINARY) 	 
+#endif /* UNICODE_SUPPORT */
 			putlen = cbValue;
 		else
 			putlen = ctype_length(ctype);
@@ -1056,7 +1051,8 @@ PGAPI_PutData(
 			}
 
 			/* store the oid */
-			current_pdata->lobj_oid = lo_creat(conn, INV_READ | INV_WRITE);
+			current_pdata->lobj_oid = lo_creat(conn->pgconn, INV_READ | INV_WRITE);
+
 			if (current_pdata->lobj_oid == 0)
 			{
 				SC_set_error(stmt, STMT_EXEC_ERROR, "Couldnt create large object.");
@@ -1071,7 +1067,7 @@ PGAPI_PutData(
 			/***current_param->EXEC_buffer = (char *) &current_param->lobj_oid;***/
 
 			/* store the fd */
-			estmt->lobj_fd = lo_open(conn, current_pdata->lobj_oid, INV_WRITE);
+			estmt->lobj_fd = lo_open(conn->pgconn, current_pdata->lobj_oid, INV_WRITE);
 			if (estmt->lobj_fd < 0)
 			{
 				SC_set_error(stmt, STMT_EXEC_ERROR, "Couldnt open large object for writing.");
@@ -1079,7 +1075,7 @@ PGAPI_PutData(
 				return SQL_ERROR;
 			}
 
-			retval = lo_write(conn, estmt->lobj_fd, putbuf, putlen);
+			retval = lo_write(conn->pgconn, estmt->lobj_fd, putbuf, putlen);
 			mylog("lo_write: cbValue=%d, wrote %d bytes\n", putlen, retval);
 		}
 		else
@@ -1104,7 +1100,7 @@ PGAPI_PutData(
 		if (current_iparam->PGType == conn->lobj_type)
 		{
 			/* the large object fd is in EXEC_buffer */
-			retval = lo_write(conn, estmt->lobj_fd, putbuf, putlen);
+			retval = lo_write(conn->pgconn, estmt->lobj_fd, putbuf, putlen);
 			mylog("lo_write(2): cbValue = %d, wrote %d bytes\n", putlen, retval);
 
 			*current_pdata->EXEC_used += putlen;
