@@ -91,7 +91,7 @@ RETCODE SQL_API	SQLSetConnectAttrW(HDBC hdbc,
 /*      new function */
 RETCODE  SQL_API
 SQLSetDescFieldW(SQLHDESC DescriptorHandle, SQLSMALLINT RecNumber,
-				SQLSMALLINT FieldIdentifier, PTR Value, 
+				SQLSMALLINT FieldIdentifier, PTR Value,
 				SQLINTEGER BufferLength)
 {
 	RETCODE	ret;
@@ -138,7 +138,7 @@ SQLGetDescFieldW(SQLHDESC hdesc, SQLSMALLINT iRecord, SQLSMALLINT iField,
 {
 	RETCODE	ret;
 	BOOL	alloced = FALSE;
-	SQLINTEGER	blen, bMax, *pcbV;
+	SQLINTEGER	blen=0, bMax, *pcbV;
         char    *rgbV = NULL;
 
 	mylog("[SQLGetDescFieldW]");
@@ -232,20 +232,20 @@ RETCODE SQL_API SQLColAttributeW(
 	SQLUSMALLINT	iCol,
 	SQLUSMALLINT	iField,
 	SQLPOINTER		pCharAttr,
-	SQLSMALLINT		cbCharAttrMax,	
+	SQLSMALLINT		cbCharAttrMax,
 	SQLSMALLINT  *pcbCharAttr,
 	SQLPOINTER		pNumAttr)
 {
 	RETCODE	ret;
 	BOOL	alloced = FALSE;
-	SQLSMALLINT	*rgbL, blen, bMax;
+	SQLSMALLINT	*rgbL, blen=0, bMax;
         char    *rgbD = NULL;
 
 	mylog("[SQLColAttributeW]");
 	ENTER_STMT_CS((StatementClass *) hstmt);
 	SC_clear_error((StatementClass *) hstmt);
 	switch (iField)
-	{ 
+	{
 		case SQL_DESC_BASE_COLUMN_NAME:
 		case SQL_DESC_BASE_TABLE_NAME:
 		case SQL_DESC_CATALOG_NAME:
@@ -302,13 +302,13 @@ RETCODE SQL_API SQLGetDiagFieldW(
 {
 	RETCODE	ret;
 	BOOL	alloced = FALSE;
-	SQLSMALLINT	*rgbL, blen, bMax;
+	SQLSMALLINT	*rgbL, blen=0, bMax;
         char    *rgbD = NULL;
 
 	mylog("[[SQLGetDiagFieldW]] Handle=(%u,%x) Rec=%d Id=%d\n", fHandleType,
 			handle, iRecord, fDiagField);
 	switch (fDiagField)
-	{ 
+	{
 		case SQL_DIAG_DYNAMIC_FUNCTION:
 		case SQL_DIAG_CLASS_ORIGIN:
 		case SQL_DIAG_CONNECTION_NAME:
