@@ -488,6 +488,7 @@ PGAPI_SetConnectOption(
 				if (fOption == 30002 && vParam)
 				{
 					int	cmp;
+#ifdef UNICODE_SUPPORT
 					char *asPara;
 					if (conn->unicode)
 					{
@@ -496,6 +497,7 @@ PGAPI_SetConnectOption(
 						free(asPara);
 					}
 					else
+#endif
 						cmp = strncmp((char *) vParam, "Microsoft Jet", 13);
 					
 					if (0 == cmp)
@@ -643,7 +645,6 @@ PGAPI_GetStmtOption(
 	CSTR func = "PGAPI_GetStmtOption";
 	StatementClass *stmt = (StatementClass *) hstmt;
 	QResultClass *res;
-	ConnInfo   *ci = &(SC_get_conn(stmt)->connInfo);
 	int	ridx;
 
 	mylog("%s: entering...\n", func);
