@@ -17,10 +17,6 @@
 #include "dlg_specific.h"
 #include "environ.h"
 
-#ifdef WIN32
-#include <winsock.h>
-#endif
-
 GLOBAL_VALUES globals;
 
 RETCODE SQL_API SQLDummyOrdinal(void);
@@ -87,28 +83,10 @@ HINSTANCE NEAR s_hModule;		/* Saved module handle. */
 BOOL		WINAPI
 DllMain(HANDLE hInst, ULONG ul_reason_for_call, LPVOID lpReserved)
 {
-	WORD		wVersionRequested;
-	WSADATA		wsaData;
-
 	switch (ul_reason_for_call)
 	{
 		case DLL_PROCESS_ATTACH:
 			s_hModule = hInst;	/* Save for dialog boxes */
-
-			/* Load the WinSock Library */
-			wVersionRequested = MAKEWORD(1, 1);
-
-			if (WSAStartup(wVersionRequested, &wsaData))
-				return FALSE;
-
-			/* Verify that this is the minimum version of WinSock */
-			if (LOBYTE(wsaData.wVersion) != 1 ||
-				HIBYTE(wsaData.wVersion) != 1)
-			{
-				WSACleanup();
-				return FALSE;
-			}
-
 			initialize_global_cs();
 			getCommonDefaults(DBMS_NAME, ODBCINST_INI, NULL);
 			break;
@@ -118,7 +96,6 @@ DllMain(HANDLE hInst, ULONG ul_reason_for_call, LPVOID lpReserved)
 
 		case DLL_PROCESS_DETACH:
 			finalize_global_cs();
-			WSACleanup();
 			return TRUE;
 
 		case DLL_THREAD_DETACH:
