@@ -5,7 +5,7 @@
  *
  * Comments:		See "notice.txt" for copyright and license information.
  *
- * $Id: psqlodbc.h,v 1.88 2005/02/14 13:07:11 dpage Exp $
+ * $Id: psqlodbc.h,v 1.93 2005/10/20 13:06:10 petere Exp $
  *
  */
 
@@ -20,6 +20,7 @@
 
 #include <stdio.h>				/* for FILE* pointers: see GLOBAL_VALUES */
 #ifdef POSIX_MULTITHREAD_SUPPORT
+#define _XOPEN_SOURCE
 #include <pthread.h>
 #endif
 #include "version.h"
@@ -42,7 +43,7 @@
 
 #include <sql.h>
 #include <sqlext.h>
-#if !defined(WIN32)
+#if defined(UNICODE_SUPPORT) && !defined(WIN32)
 # include <sqlucode.h>
 #endif
 
@@ -90,10 +91,6 @@ typedef double SDOUBLE;
 
 #endif
 
-
-typedef UInt4 Oid;
-
-
 #ifndef FALSE
 #define FALSE	(BOOL)0
 #endif
@@ -123,13 +120,21 @@ typedef UInt4 Oid;
 #endif
 
 /* Driver stuff */
-
-#define DRIVERNAME				"PostgreSQL ODBC"
-#define DRIVER_ODBC_VER				"03.00"
 #define DBMS_NAME				"PostgreSQL"
+#define DRIVER_ODBC_VER				"03.00"
+
+#ifdef  UNICODE_SUPPORT 	 
+#define DRIVERNAME				"PostgreSQL Unicode"	 
+#else
+#define DRIVERNAME				"PostgreSQL ANSI"
+#endif /* UNICODE_SUPPORT */
 
 #ifdef WIN32
-#define DRIVER_FILE_NAME			"PSQLODBC.DLL"
+#ifdef  UNICODE_SUPPORT
+#define DRIVER_FILE_NAME			"PSQLODBCW.DLL"
+#else
+#define DRIVER_FILE_NAME			"PSQLODBCA.DLL"
+#endif
 #else
 #define DRIVER_FILE_NAME			"libpsqlodbc.so"
 #endif   /* WIN32 */
@@ -143,7 +148,8 @@ typedef UInt4 Oid;
 							 /* see an easy way round this - DJP 24-1-2001 */
 #define MAX_CONNECT_STRING			4096
 #define ERROR_MSG_LENGTH			4096
-#define FETCH_MAX				100 	/* default number of rows to cache
+#define SQLSTATE_LENGTH				8
+#define FETCH_MAX					100 	/* default number of rows to cache
 							 * for declare/fetch */
 #define TUPLE_MALLOC_INC			100
 #define SOCK_BUFFER_SIZE			8192	/* default socket buffer
@@ -205,7 +211,6 @@ typedef UInt4 Oid;
 typedef struct ConnectionClass_ ConnectionClass;
 typedef struct StatementClass_ StatementClass;
 typedef struct QResultClass_ QResultClass;
-typedef struct SocketClass_ SocketClass;
 typedef struct BindInfoClass_ BindInfoClass;
 typedef struct ParameterInfoClass_ ParameterInfoClass;
 typedef struct ParameterImplClass_ ParameterImplClass;
@@ -278,7 +283,7 @@ typedef struct
         SDWORD  errorsize;
         SWORD   recsize;
         SWORD   errorpos;
-        char    sqlstate[8];
+        char    sqlstate[SQLSTATE_LENGTH];
         Int4    diag_row_count;
         char    __error_message[1];
 }       PG_ErrorInfo;
@@ -322,11 +327,13 @@ int	initialize_global_cs(void);
 #ifdef	POSIX_THREADMUTEX_SUPPORT
 const pthread_mutexattr_t *getMutexAttr(void);
 #endif /* POSIX_THREADMUTEX_SUPPORT */
+#ifdef  UNICODE_SUPPORT
 #define WCLEN sizeof(SQLWCHAR)
 UInt4	ucs2strlen(const SQLWCHAR *ucs2str);
 char	*ucs2_to_utf8(const SQLWCHAR *ucs2str, Int4 ilen, UInt4 *olen, BOOL tolower);
 UInt4	utf8_to_ucs2_lf(const char * utf8str, Int4 ilen, BOOL lfconv, SQLWCHAR *ucs2str, UInt4 buflen);
 #define	utf8_to_ucs2(utf8str, ilen, ucs2str, buflen) utf8_to_ucs2_lf(utf8str, ilen, FALSE, ucs2str, buflen)
+#endif /* UNICODE_SUPPORT */
 
 /*#define	_MEMORY_DEBUG_ */
 #ifdef	_MEMORY_DEBUG_
