@@ -50,13 +50,6 @@ PGAPI_RowCount(
 		return SQL_INVALID_HANDLE;
 	}
 	ci = &(SC_get_conn(stmt)->connInfo);
-	if (stmt->manual_result)
-	{
-		if (pcrow)
-			*pcrow = -1;
-		return SQL_SUCCESS;
-	}
-
 	res = SC_get_Curres(stmt);
 	if (res && pcrow)
 	{
@@ -849,24 +842,37 @@ inolog("GetData Column 0 is type %d not of type SQL_C_BOOKMARK", fCType);
 			return SQL_ERROR;
 		}
 	}
-
-	if (stmt->manual_result || !SC_is_fetchcursor(stmt))
+	if (stmt->manual_result)
 	{
-		/* make sure we're positioned on a valid row */
-		num_rows = QR_get_num_total_tuples(res);
-		if ((stmt->currTuple < 0) ||
-			(stmt->currTuple >= num_rows))
+		if(!SC_is_fetchcursor(stmt))
 		{
-			SC_set_error(stmt, STMT_INVALID_CURSOR_STATE_ERROR, "Not positioned on a valid row for GetData.");
-			SC_log_error(func, "", stmt);
-			return SQL_ERROR;
+			/* make sure we're positioned on a valid row */
+			num_rows = QR_get_num_total_tuples(res);
+			if ((stmt->currTuple < 0) ||
+				(stmt->currTuple >= num_rows))
+			{
+				SC_set_error(stmt, STMT_INVALID_CURSOR_STATE_ERROR, "Not positioned on a valid row for GetData.");
+				SC_log_error(func, "", stmt);
+				return SQL_ERROR;
+			}
+		}
+		else
+		{
+			if (stmt->currTuple < 0)
+			{
+				SC_set_error(stmt, STMT_INVALID_CURSOR_STATE_ERROR, "Not positioned on a valid row for GetData.");
+				SC_log_error(func, "", stmt);
+				return SQL_ERROR;
+			}
 		}
-		mylog("     num_rows = %d\n", num_rows);
 
 		if (!get_bookmark)
 		{
 			if (stmt->manual_result)
-				value = QR_get_value_manual(res, stmt->currTuple, icol);
+				if(SC_is_fetchcursor(stmt))
+					value = QR_get_value_manual(res, (stmt->currTuple % stmt->hdbc->connInfo.drivers.fetch_max), icol);
+				else
+					value = QR_get_value_manual(res, stmt->currTuple, icol);
 			else
 			{
 				Int4	curt = GIdx2ResultIdx(stmt->currTuple, stmt, res);
@@ -1151,8 +1157,7 @@ PGAPI_ExtendedFetch(
 	}
 	ci = &(SC_get_conn(stmt)->connInfo);
 
-	/* if (SC_is_fetchcursor(stmt) && !stmt->manual_result) */
-	if (SQL_CURSOR_FORWARD_ONLY == stmt->options.cursor_type && !stmt->manual_result)
+	if (SQL_CURSOR_FORWARD_ONLY == stmt->options.cursor_type)
 	{
 		if (fFetchType != SQL_FETCH_NEXT)
 		{
@@ -1293,13 +1298,13 @@ PGAPI_ExtendedFetch(
 					EXTFETCH_RETURN_BOF(stmt, res)
 				}
 #else
-				if (stmt->rowset_start < opts->rowset_size)
+				if (stmt->rowset_start < opts->size_of_rowset)
 				{
 					SC_set_error(stmt, STMT_POS_BEFORE_RECORDSET, "fetch prior and before the beggining");
 					stmt->rowset_start = 0;
 				}
 				else
-					stmt->rowset_start -= opts->rowset_size;
+					stmt->rowset_start -= opts->size_of_rowset;
 #endif /* DRIVER_CURSOR_IMPLEMENT */
 			}
 			break;
@@ -1412,10 +1417,12 @@ PGAPI_ExtendedFetch(
 	 * Handle Declare Fetch style specially because the end is not really
 	 * the end...
 	 */
-	if (SC_is_fetchcursor(stmt) && !stmt->manual_result)
+	if (SC_is_fetchcursor(stmt) )
 	{
-		if (QR_end_tuples(res))
+		if(!stmt->manual_result)
+		{
 			return SQL_NO_DATA_FOUND;
+		}
 	}
 	else
 	{
@@ -1475,6 +1482,7 @@ PGAPI_ExtendedFetch(
 	{
 		stmt->bind_row = i;		/* set the binding location */
 		result = SC_fetch(stmt);
+		res = SC_get_Curres(stmt);
 #ifdef	DRIVER_CURSOR_IMPLEMENT
 		if (SQL_SUCCESS_WITH_INFO == result && 0 == stmt->last_fetch_count && res->keyset)
 		{
@@ -1601,8 +1609,8 @@ static void getTid(const QResultClass *res, int index, UInt4 *blocknum, UInt2 *o
 static void KeySetSet(const TupleField *tuple, int num_fields, KeySet *keyset)
 {
 	sscanf(tuple[num_fields - 2].value, "(%u,%hu)",
-			&keyset->blocknum, &keyset->offset);
-	sscanf(tuple[num_fields - 1].value, "%u", &keyset->oid);
+		   (unsigned int *) &keyset->blocknum, &keyset->offset);
+	sscanf(tuple[num_fields - 1].value, "%u", (unsigned int *) &keyset->oid);
 }
 
 static void DiscardDeleted(QResultClass *res, int index);
@@ -2031,7 +2039,7 @@ static int LoadFromKeyset(StatementClass *stmt, QResultClass * res, int rows_per
 						else
 							keys_per_fetch = rows_per_fetch;
 						lodlen = strlen(stmt->load_statement);
-						sprintf(planname, "_KEYSET_%0x", res);
+						sprintf(planname, "_KEYSET_%p", res);
 						allen = 8 + strlen(planname) +
 							3 + 4 * keys_per_fetch + 1
 							+ 1 + 2 + lodlen + 20 +
@@ -2085,7 +2093,7 @@ static int LoadFromKeyset(StatementClass *stmt, QResultClass * res, int rows_per
 			}
 			if (res->reload_count > 0)
 			{
-				sprintf(qval, "EXECUTE \"_KEYSET_%x\"(", res);
+				sprintf(qval, "EXECUTE \"_KEYSET_%p\"(", res);
 				sval = qval;
 			}
 			else
@@ -2120,14 +2128,8 @@ SC_pos_reload_needed(StatementClass *stmt, UDWORD flag)
 	Int4		i, limitrow;
 	UWORD		qcount;
 	QResultClass	*res;
-	IRDFields	*irdflds = SC_get_IRDF(stmt);
 	RETCODE		ret = SQL_ERROR;
-	ConnectionClass	*conn = SC_get_conn(stmt);
-	/**** UInt4		oid, blocknum, lodlen;
-	UWORD		offset;
-	char		*sval; ****/
-	char		*qval = NULL;
-	Int4		rowc, rows_per_fetch;
+	Int4		rowc, rows_per_fetch=0;
 	BOOL		create_from_scratch = (0 != flag);
 
 	mylog("SC_pos_reload_needed\n");
@@ -2458,7 +2460,6 @@ SC_pos_update(StatementClass *stmt,
 	{
 		HSTMT		hstmt;
 		int			j;
-		int			res_cols = QR_NumResultCols(s.res);
 		ConnInfo	*ci = &(conn->connInfo);
 		APDFields	*apdopts;
 		Int4		fieldtype = 0;
@@ -2535,9 +2536,7 @@ SC_pos_delete(StatementClass *stmt,
 	UWORD		offset;
 	QResultClass *res, *qres;
 	ConnectionClass	*conn = SC_get_conn(stmt);
-	ARDFields	*opts = SC_get_ARDF(stmt);
 	IRDFields	*irdflds = SC_get_IRDF(stmt);
-	BindInfoClass *bindings = opts->bindings;
 	char		dltstr[4096];
 	RETCODE		ret;
 	UInt4		oid, blocknum, qflag;
@@ -2673,7 +2672,7 @@ irow_insert(RETCODE ret, StatementClass *stmt, StatementClass *istmt, int addpos
 				char	buf[32];
 				UInt4	offset = opts->row_offset_ptr ? *opts->row_offset_ptr : 0;
 
-				sprintf(buf, "%lu", addpos + 1);
+				sprintf(buf, "%d", addpos + 1);
 				SC_set_current_col(stmt, -1);
 				copy_and_convert_field(stmt,
 					PG_TYPE_INT4,
@@ -3053,7 +3052,9 @@ PGAPI_SetPos(
 {
 	CSTR func = "PGAPI_SetPos";
 	RETCODE	ret;
-	ConnectionClass	*conn;
+#ifdef	DRIVER_CURSOR_IMPLEMENT
+    ConnectionClass *conn;
+#endif
 	int		num_cols, i, rowsetSize;
 	GetDataClass	*gdata = NULL;
 	spos_cdata	s;
