@@ -1062,7 +1062,10 @@ SC_fetch(StatementClass *self)
 
 			if (self->manual_result)
 			{
-				value = QR_get_value_manual(res, (self->currTuple >= ci->drivers.fetch_max) ? (self->currTuple % ci->drivers.fetch_max) : self->currTuple, lf);
+                if (ci->drivers.use_declarefetch)
+				    value = QR_get_value_manual(res, (self->currTuple >= ci->drivers.fetch_max) ? (self->currTuple % ci->drivers.fetch_max) : self->currTuple, lf);
+                else
+                    value = QR_get_value_manual(res, self->currTuple, lf);
 				mylog("manual_result\n");
 			}
 			else if (SC_is_fetchcursor(self))
