@@ -150,6 +150,7 @@ struct StatementClass_
 	STMT_Status status;
 	char	   *__error_message;
 	int			__error_number;
+	char		__sqlstate[SQLSTATE_LENGTH];
 
 	Int4		currTuple;		/* current absolute row number (GetData,
 								 * SetPos, SQLFetch) */
@@ -252,7 +253,7 @@ struct StatementClass_
 #define	SC_get_errornumber(a) (a->__error_number)
 #define	SC_set_errornumber(a, n) (a->__error_number = n)
 #define	SC_get_errormsg(a) (a->__error_message)
-#define	SC_is_lower_case(a, b) (a->options.metadata_id, b->connInfo.lower_case_identifier)
+#define	SC_is_lower_case(a, b) (a->options.metadata_id || b->connInfo.lower_case_identifier)
 
 #define	SC_MALLOC_return_with_error(t, tp, s, a, m, r) \
 	{ \
@@ -299,12 +300,13 @@ struct StatementClass_
 #define DELETE_STMT_CS(x)	pthread_mutex_destroy(&((x)->cs))
 #else
 #define INIT_STMT_CS(x)
-#define ENTER_STMT_CS(x)
-#define LEAVE_STMT_CS(x)
+#define ENTER_STMT_CS(x)	((void)(0))
+#define LEAVE_STMT_CS(x)	((void)(0))
 #define DELETE_STMT_CS(x)
 #endif /* WIN_MULTITHREAD_SUPPORT */
 /*	Statement prototypes */
 StatementClass *SC_Constructor(void);
+void		SC_set_handle(StatementClass *self,QResultClass *res);
 void		InitializeStatementOptions(StatementOptions *opt);
 char		SC_Destructor(StatementClass *self);
 BOOL		SC_opencheck(StatementClass *self, const char *func);
@@ -322,6 +324,8 @@ void		SC_error_copy(StatementClass *self, const StatementClass *from);
 void		SC_full_error_copy(StatementClass *self, const StatementClass *from);
 char		SC_get_error(StatementClass *self, int *number, char **message);
 char		*SC_create_errormsg(const StatementClass *self);
+void		SC_set_sqlstate(StatementClass *self, const char *sqlstate);
+char		*SC_get_sqlstate(StatementClass *self);
 void		SC_set_prepared(StatementClass *self, BOOL);
 RETCODE		SC_initialize_stmts(StatementClass *self, BOOL);
 RETCODE		SC_execute(StatementClass *self);
